@@ -2,7 +2,7 @@ package Backblaze::B2V2Client;
 # API client library for V2 of the API to Backblaze B2 object storage
 # Allows for creating/deleting buckets, listing files in buckets, and uploading/downloading files
 
-$Backblaze::B2V2Client::VERSION = '1.3';
+$Backblaze::B2V2Client::VERSION = '1.4';
 
 # our dependencies:
 use Cpanel::JSON::XS;
@@ -14,6 +14,7 @@ use WWW::Mechanize;
 
 # I wish I could apply this to my diet.
 use strict;
+use warnings;
 
 # object constructor; will automatically authorize this session
 sub new {
@@ -752,10 +753,6 @@ __END__
 
 Backblaze::B2V2Client - Client library for the Backblaze B2 Cloud Storage Service V2 API.
 
-=head1 VERSION
-
-1.0 - Initial working version.
-
 =head1 SYNOPSIS
 
 	use Backblaze::B2V2Client;
@@ -830,6 +827,21 @@ Key again, so copy it immediately.
 Please store the Application Key pair in a secure way, preferably encrypted
 when not in use by your software.
 
+=head2 New: b2_client Command Line Utility
+
+Backblaze::B2V2Client now includes the 'b2_client' command line utility to
+easily download or upload files from B2.  Please execute 'b2_client help'
+for more details, and here are a few examples:
+
+	# download a file to current directory
+	b2_client get MyPictures FamilyPhoto.jpg
+	
+	# download a file to a target directory
+	b2_client get MyPictures FamilyPhoto.jpg /home/ginger/photos
+	
+	# upload a file to B2
+	b2_client put MyPictures /home/ginger/photos/AnotherFamilyPhoto.jpg
+
 =head2 BackBlaze B2 also has a S3-compatible API
 
 Backblaze has added an S3-compatible API, which you can read about here:
